@@ -20,8 +20,7 @@
  */
 #include <goffice/goffice-config.h>
 #include "goffice-gtk.h"
-
-#include <goffice/app/go-cmd-context.h>
+//#include <goffice/app/go-cmd-context.h>
 #include <goffice/utils/go-file.h>
 #include <goffice/goffice-priv.h>
 #include <gtk/gtk.h>
@@ -77,11 +76,11 @@ go_gtk_button_new_with_stock (char const *text, char const* stock_id)
  *
  * Creates and adds a button with stock image to the action area of an existing dialog.
  * Code from gedit
- * 
+ *
  * return : newly created button
  **/
 GtkWidget*
-go_gtk_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
+go_gtk_dialog_add_button (GtkDialog *dialog, char const* text, char const* stock_id,
 			  gint response_id)
 {
 	GtkWidget *button;
@@ -93,15 +92,16 @@ go_gtk_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* sto
 	button = go_gtk_button_new_with_stock (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
-	gtk_dialog_add_action_widget (dialog, button, response_id);	
+	gtk_dialog_add_action_widget (dialog, button, response_id);
 
 	return button;
 }
 
+
 #if 0 /* dropped, since abiword doesn't depend on libglade */
 
 
@@ -138,11 +138,17 @@ go_libglade_new (char const *gladefile, char const *root,
 }
 
 #endif
-
+static void
+cb_activate_default (GtkWindow *window)
+{
+	GtkWidget *w = gtk_window_get_default_widget (window);
+	if (w && gtk_widget_is_sensitive (w))
+		gtk_widget_activate (w);
+}
 /**
  * go_gtk_editable_enters:
  * @window:
- * @w: 
+ * @w:
  *
  * Normally if there's an editable widget (such as #GtkEntry) in your
  * dialog, pressing Enter will activate the editable rather than the
@@ -150,13 +156,14 @@ go_libglade_new (char const *gladefile, char const *root,
  * type something in and then press enter to close the dialog. This
  * function enables that behavior.
  **/
+
 void
 go_gtk_editable_enters (GtkWindow *window, GtkWidget *w)
 {
 	g_return_if_fail (GTK_IS_WINDOW (window));
 	g_signal_connect_swapped (G_OBJECT (w),
 		"activate",
-		G_CALLBACK (gtk_window_activate_default), window);
+		G_CALLBACK (cb_activate_default), window);
 }
 
 GdkPixbuf *
@@ -189,11 +196,11 @@ go_gtk_widget_disable_focus (GtkWidget *w)
 	if (GTK_IS_CONTAINER (w))
 		gtk_container_foreach (GTK_CONTAINER (w),
 			(GtkCallback) go_gtk_widget_disable_focus, NULL);
-	GTK_WIDGET_UNSET_FLAGS (w, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (w, FALSE);
 }
 
 int
-go_pango_measure_string (PangoContext *context, const PangoFontDescription *font_desc, const char *str)
+go_pango_measure_string (PangoContext *context, PangoFontDescription const *font_desc, char const *str)
 {
 	PangoLayout *layout = pango_layout_new (context);
 	int width;
@@ -206,11 +213,10 @@ go_pango_measure_string (PangoContext *context, const PangoFontDescription *font
 
 	return width;
 }
-
 static void
 cb_parent_mapped (GtkWidget *parent, GtkWindow *window)
 {
-	if (GTK_WIDGET_MAPPED (window)) {
+	if (gtk_widget_get_mapped (GTK_WIDGET (window))) {
 		gtk_window_present (window);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (parent),
 			G_CALLBACK (cb_parent_mapped), window);
@@ -230,29 +236,30 @@ cb_parent_mapped (GtkWidget *parent, GtkWindow *window)
 void
 go_gtk_window_set_transient (GtkWindow *toplevel, GtkWindow *window)
 {
-/* FIXME:                                                                     */
-/* 	GtkWindowPosition position = gnome_preferences_get_dialog_position(); */
+#if 0
+	GtkWindowPosition position = gnome_preferences_get_dialog_position(); */
+	if (position == GTK_WIN_POS_NONE)
+		position = GTK_WIN_POS_CENTER_ON_PARENT;
+#else
 	GtkWindowPosition position = GTK_WIN_POS_CENTER_ON_PARENT;
+#endif
 
 	g_return_if_fail (GTK_IS_WINDOW (toplevel));
 	g_return_if_fail (GTK_IS_WINDOW (window));
 
 	gtk_window_set_transient_for (window, toplevel);
 
-	if (position == GTK_WIN_POS_NONE)
-		position = GTK_WIN_POS_CENTER_ON_PARENT;
 	gtk_window_set_position (window, position);
 
-	if (!GTK_WIDGET_MAPPED (toplevel))
+	if (!gtk_widget_get_mapped (GTK_WIDGET (toplevel)))
 		g_signal_connect_after (G_OBJECT (toplevel),
 			"map",
 			G_CALLBACK (cb_parent_mapped), window);
 }
-
 static gint
 cb_non_modal_dialog_keypress (GtkWidget *w, GdkEventKey *e)
 {
-	if(e->keyval == GDK_Escape) {
+	if(e->keyval == GDK_KEY_Escape) {
 		gtk_widget_destroy (w);
 		return TRUE;
 	}
@@ -260,6 +267,7 @@ cb_non_modal_dialog_keypress (GtkWidget *w, GdkEventKey *e)
 	return FALSE;
 }
 
+
 void
 go_gtk_nonmodal_dialog (GtkWindow *toplevel, GtkWindow *dialog)
 {
@@ -271,7 +279,7 @@ go_gtk_nonmodal_dialog (GtkWindow *toplevel, GtkWindow *dialog)
 
 static void
 fsel_response_cb (GtkFileChooser *dialog,
-		  gint response_id,
+		 G_GNUC_UNUSED gint response_id,
 		  gboolean *result)
 {
 	if (response_id == GTK_RESPONSE_OK) {
@@ -286,15 +294,17 @@ fsel_response_cb (GtkFileChooser *dialog,
 	gtk_main_quit ();
 }
 
+
 static gint
 gu_delete_handler (GtkDialog *dialog,
-		   GdkEventAny *event,
-		   gpointer data)
+		  G_GNUC_UNUSED GdkEventAny *event,
+		   G_GNUC_UNUSED gpointer data)
 {
 	gtk_dialog_response (dialog, GTK_RESPONSE_CANCEL);
 	return TRUE; /* Do not destroy */
 }
 
+
 gboolean
 go_gtk_file_sel_dialog (GtkWindow *toplevel, GtkWidget *w)
 {
@@ -311,7 +321,7 @@ go_gtk_file_sel_dialog (GtkWindow *toplevel, GtkWidget *w)
 	delete_handler = g_signal_connect (w, "delete_event",
 		G_CALLBACK (gu_delete_handler), NULL);
 
-	gtk_widget_show_all (w);
+	gtk_widget_show (w);
 	gtk_grab_add (w);
 	gtk_main ();
 
@@ -320,23 +330,24 @@ go_gtk_file_sel_dialog (GtkWindow *toplevel, GtkWidget *w)
 	return result;
 }
 
+
 static gboolean have_pixbufexts = FALSE;
 static GSList *pixbufexts = NULL;  /* FIXME: we leak this.  */
 
 static gboolean
-filter_images (const GtkFileFilterInfo *filter_info, gpointer data)
+filter_images (const GtkFileFilterInfo *filter_info, G_GNUC_UNUSED gpointer data)
 {
 	if (filter_info->mime_type)
 		return strncmp (filter_info->mime_type, "image/", 6) == 0;
 
 	if (filter_info->display_name) {
 		GSList *l;
-		const char *ext = strrchr (filter_info->display_name, '.');
+		char const *ext = strrchr (filter_info->display_name, '.');
 		if (!ext) return FALSE;
 		ext++;
 
 		if (!have_pixbufexts) {
-			GSList *l, *pixbuf_fmts = gdk_pixbuf_get_formats ();
+			GSList *pixbuf_fmts = gdk_pixbuf_get_formats ();
 
 			for (l = pixbuf_fmts; l != NULL; l = l->next) {
 				GdkPixbufFormat *fmt = l->data;
@@ -365,6 +376,7 @@ filter_images (const GtkFileFilterInfo *filter_info, gpointer data)
 	return FALSE;
 }
 
+
 static void
 update_preview_cb (GtkFileChooser *chooser)
 {
@@ -455,7 +467,7 @@ gui_image_chooser_new (gboolean is_save)
 
 	/* Preview */
 	{
-		GtkWidget *vbox = gtk_vbox_new (FALSE, 2);
+		GtkWidget *vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
 		GtkWidget *preview_image = gtk_image_new ();
 		GtkWidget *preview_label = gtk_label_new ("");
 
@@ -474,10 +486,11 @@ gui_image_chooser_new (gboolean is_save)
 	return fsel;
 }
 
+
 char *
-go_gtk_select_image (GtkWindow *toplevel, const char *initial)
+go_gtk_select_image (GtkWindow *toplevel, char const *initial)
 {
-	const char *key = "go_gtk_select_image";
+	char const *key = "go_gtk_select_image";
 	char *uri = NULL;
 	GtkFileChooser *fsel;
 
@@ -502,6 +515,7 @@ go_gtk_select_image (GtkWindow *toplevel, const char *initial)
 	return uri;
 }
 
+
 /**
  * gui_get_image_save_info:
  * @toplevel: a #GtkWindow
@@ -516,7 +530,7 @@ go_gtk_select_image (GtkWindow *toplevel, const char *initial)
  * export resolution in @resolution.
  **/
 
-typedef struct {
+/*typedef struct {
 	char *uri;
 	double resolution;
 	gboolean is_expanded;
@@ -524,7 +538,7 @@ typedef struct {
 } SaveInfoState;
 
 static void
-save_info_state_free (SaveInfoState *state) 
+save_info_state_free (SaveInfoState *state)
 {
 	g_free (state->uri);
 	g_free (state);
@@ -536,11 +550,11 @@ cb_format_combo_changed (GtkComboBox *combo, GtkWidget *expander)
 	GOImageFormatInfo const *format_info;
 
 	format_info = go_image_get_format_info (gtk_combo_box_get_active (combo));
-	gtk_widget_set_sensitive (expander, 
-				  format_info != NULL && 
+	gtk_widget_set_sensitive (expander,
+				  format_info != NULL &&
 				  format_info->is_dpi_useful);
 }
-
+*/
 #if 0 /* dropped, since abiword doesn't depend on libglade */
 
 char *
@@ -573,8 +587,8 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 
 	g_object_set (G_OBJECT (fsel), "title", _("Save as"), NULL);
 
-	gui = go_libglade_new ("go-image-save-dialog-extra.glade", 
-			       "image_save_dialog_extra", 
+	gui = go_libglade_new ("go-image-save-dialog-extra.glade",
+			       "image_save_dialog_extra",
 			       GETTEXT_PACKAGE, NULL);
 	if (gui != NULL) {
 		GtkWidget *widget;
@@ -587,8 +601,8 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			for (l = supported_formats, i = 0; l != NULL; l = l->next, i++) {
 				format = GPOINTER_TO_UINT (l->data);
 				format_info = go_image_get_format_info (format);
-				gtk_combo_box_append_text (format_combo, _(format_info->desc)); 
-				if (format == state->format) 
+				gtk_combo_box_append_text (format_combo, _(format_info->desc));
+				if (format == state->format)
 					gtk_combo_box_set_active (format_combo, i);
 			}
 			if (gtk_combo_box_get_active (format_combo) < 0)
@@ -604,7 +618,7 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			gtk_expander_set_expanded (GTK_EXPANDER (expander), state->is_expanded);
 			resolution_spin = glade_xml_get_widget (gui, "resolution_spin");
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (resolution_spin), state->resolution);
-		} else 
+		} else
 			gtk_widget_hide (expander);
 
 		if (resolution != NULL && supported_formats != NULL && ret_format != NULL) {
@@ -612,9 +626,9 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			gtk_file_chooser_set_extra_widget (fsel, widget);
 
 			resolution_table = glade_xml_get_widget (gui, "resolution_table");
-		
-			cb_format_combo_changed (format_combo, resolution_table);	
-			g_signal_connect (GTK_WIDGET (format_combo), "changed", 
+
+			cb_format_combo_changed (format_combo, resolution_table);
+			g_signal_connect (GTK_WIDGET (format_combo), "changed",
 					  G_CALLBACK (cb_format_combo_changed), resolution_table);
 		}
 
@@ -625,7 +639,7 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 		gtk_file_chooser_set_uri (fsel, state->uri);
 		gtk_file_chooser_unselect_all (fsel);
 	}
-	
+
 	/* Show file selector */
  loop:
 	if (!go_gtk_file_sel_dialog (toplevel, GTK_WIDGET (fsel)))
@@ -634,8 +648,8 @@ gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 	if (format_combo) {
 		char *new_uri = NULL;
 
-		format = GPOINTER_TO_UINT (g_slist_nth_data 
-			(supported_formats, 
+		format = GPOINTER_TO_UINT (g_slist_nth_data
+			(supported_formats,
 			 gtk_combo_box_get_active (format_combo)));
 		format_info = go_image_get_format_info (format);
 		if (!go_url_check_extension (uri, format_info->ext, &new_uri) &&
@@ -688,7 +702,6 @@ add_atk_relation (GtkWidget *w0, GtkWidget *w1, AtkRelationType type)
 	g_object_unref (relation_set);
 	g_object_unref (relation);
 }
-
 /**
  * go_atk_setup_label :
  * @label : #GtkWidget
@@ -704,6 +717,7 @@ go_atk_setup_label (GtkWidget *label, GtkWidget *target)
 	 add_atk_relation (target, label, ATK_RELATION_LABELLED_BY);
 }
 
+
 typedef struct {
 	char const *data_dir;
 	char const *app;
@@ -787,7 +801,7 @@ cb_help (CBHelpPaths const *paths)
 }
 
 void
-go_gtk_help_button_init (GtkWidget *w, char const *data_dir, char const *app, char const *link)
+go_gtk_help_button_init (GtkWidget *w, char const *data_dir, char const *app, char const *linkk)
 {
 	CBHelpPaths *paths = g_new (CBHelpPaths, 1);
 	GtkWidget *parent = gtk_widget_get_parent (w);
@@ -798,12 +812,13 @@ go_gtk_help_button_init (GtkWidget *w, char const *data_dir, char const *app, ch
 
 	paths->data_dir = data_dir;
 	paths->app	= app;
-	paths->link	= link;
+	paths->link	= linkk;
 	g_signal_connect_data (G_OBJECT (w), "clicked",
 		G_CALLBACK (cb_help), (gpointer) paths,
 		(GClosureNotify)g_free, G_CONNECT_SWAPPED);
 }
 
+
 /**
  * go_gtk_url_is_writeable:
  * @parent : #GtkWindow
@@ -845,28 +860,26 @@ go_gtk_url_is_writeable (GtkWindow *parent, char const *uri,
 	} else if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		char *dirname = go_dirname_from_uri (uri, TRUE);
 		char *basename = go_basename_from_uri (uri);
-		char *msg = g_markup_printf_escaped (
-			_("A file called <i>%s</i> already exists in %s.\n\n"
-			  "Do you want to save over it?"),
-			basename, dirname);
 		GtkWidget *dialog = gtk_message_dialog_new_with_markup (parent,
 			 GTK_DIALOG_DESTROY_WITH_PARENT,
 			 GTK_MESSAGE_WARNING,
 			 GTK_BUTTONS_OK_CANCEL,
-			 msg);
+			 _("A file called <i>%s</i> already exists in %s.\n\n"
+			   "Do you want to save over it?"),
+			 basename, dirname);
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 			overwrite_by_default ? GTK_RESPONSE_OK : GTK_RESPONSE_CANCEL);
 		result = GTK_RESPONSE_OK ==
 			go_gtk_dialog_run (GTK_DIALOG (dialog), parent);
 		g_free (dirname);
 		g_free (basename);
-		g_free (msg);
 	}
 
 	g_free (filename);
 	return result;
 }
 
+
 /**
  * go_gtk_dialog_run
  *
@@ -908,23 +921,23 @@ go_gtk_dialog_run (GtkDialog *dialog, GtkWindow *parent)
  */
 void
 go_gtk_notice_dialog (GtkWindow *parent, GtkMessageType type,
-		      const gchar *format, ...)
+		      char const *format, ...)
 {
 	va_list args;
 	gchar *msg;
 	GtkWidget *dialog;
 
 	VPRINTF_MESSAGE (format, args, msg);
-	dialog = gtk_message_dialog_new (parent,
+	dialog = gtk_message_dialog_new_with_markup (parent,
 		GTK_DIALOG_DESTROY_WITH_PARENT, type, GTK_BUTTONS_OK, "%s", msg);
 	g_free (msg);
-	gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
 	go_gtk_dialog_run (GTK_DIALOG (dialog), parent);
 }
 
+
 void
 go_gtk_notice_nonmodal_dialog (GtkWindow *parent, GtkWidget **ref,
-			       GtkMessageType type, const gchar *format, ...)
+			       GtkMessageType type, char const *format, ...)
 {
 	va_list args;
 	gchar *msg;
@@ -950,7 +963,7 @@ go_gtk_notice_nonmodal_dialog (GtkWindow *parent, GtkWidget **ref,
 
 gboolean
 go_gtk_query_yes_no (GtkWindow *parent, gboolean default_answer,
-		     const gchar *format, ...)
+		     char const *format, ...)
 {
 	va_list args;
 	gchar *msg;
@@ -970,6 +983,7 @@ go_gtk_query_yes_no (GtkWindow *parent, gboolean default_answer,
 		go_gtk_dialog_run (GTK_DIALOG (dialog), parent);
 }
 
+
 /**
  * go_pixbuf_new_from_file :
  * @filename :
@@ -992,9 +1006,9 @@ go_pixbuf_new_from_file (char const *filename)
 static gint
 gtk_dialog_get_response_for_widget (GtkDialog *dialog, GtkWidget *widget)
 {
-	const struct {
+	struct {
 		gint response_id;
-	} *rd = g_object_get_data (G_OBJECT (widget),
+	} const *rd = g_object_get_data (G_OBJECT (widget),
 				   "gtk-dialog-response-data");
 	if (!rd)
 		return GTK_RESPONSE_NONE;
@@ -1014,7 +1028,7 @@ gtk_dialog_get_response_for_widget (GtkDialog *dialog, GtkWidget *widget)
 void
 go_dialog_guess_alternative_button_order (GtkDialog *dialog)
 {
-	GList *children, *tmp;
+	GList *children, *ptr; //*tmp changed to *ptr
 	int i, nchildren;
 	int *new_order;
 	int i_yes = -1, i_no = -1, i_ok = -1, i_cancel = -1, i_apply = -1;
@@ -1022,15 +1036,15 @@ go_dialog_guess_alternative_button_order (GtkDialog *dialog)
 	gboolean any = FALSE;
 	int loops = 0;
 
-	children = gtk_container_get_children (GTK_CONTAINER (dialog->action_area));
+	children = gtk_container_get_children (GTK_CONTAINER (gtk_dialog_get_action_area (dialog)));
 	if (!children)
 		return;
 
 	nchildren = g_list_length (children);
 	new_order = g_new (int, nchildren);
 
-	for (tmp = children, i = 0; tmp; tmp = tmp->next, i++) {
-		GtkWidget *child = tmp->data;
+	for (ptr = children, i = 0; ptr; ptr = ptr->next, i++) {
+		GtkWidget *child = ptr->data;
 		int res = gtk_dialog_get_response_for_widget (dialog, child);
 		new_order[i] = res;
 		switch (res) {
