@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifndef __TCPWIN32ACCOUNTHANDLER__
@@ -35,19 +35,20 @@ class TCPWin32AccountHandler : public TCPAccountHandler
 {
 public:
 	TCPWin32AccountHandler();
-	
+
 	static AccountHandler*					static_constructor();
 
-	// dialog management 
+	// dialog management
 	virtual void							embedDialogWidgets(void* pEmbeddingParent);
 	virtual void							removeDialogWidgets(void* pEmbeddingParent);
+	virtual void							loadProperties();
 	virtual void							storeProperties();
 	virtual BOOL							_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam);
 	virtual bool							shouldProcessFocus();
 
 private:
 	XAP_Win32DialogHelper *					m_pWin32Dialog;
-	
+
 	// handles
 	HINSTANCE								m_hInstance;
 	HWND									m_hServerEntry;
@@ -56,8 +57,9 @@ private:
 	HWND									m_hJoinRadio;
 	HWND									m_hServerLabel;
 	HWND									m_hPortLabel;
+	HWND									m_hAllowAllCheck;
 	HWND									m_hAutoconnectCheck;
-	
+
 	void									_checkButtonHwnd(HWND hCtrl, bool bChecked);
 	bool									_isCheckedHwnd(HWND hCtrl);
 	int										_getControlTextHwnd(HWND hCtrl, int iLen, const char * p_szBuf);
