@@ -12,8 +12,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifndef __ACCOUNTHANDLER_H__
@@ -37,10 +37,6 @@
 
 class AbiCollab;
 
-using std::string;
-using std::map;
-using std::vector;
-
 typedef enum _ConnectResult
 {
 	CONNECT_SUCCESS = 0,
@@ -53,7 +49,7 @@ typedef enum _ConnectResult
 
 typedef AccountHandler* (*AccountHandlerConstructor)();
 
-typedef map<string, string> PropertyMap; 
+typedef std::map<std::string, std::string> PropertyMap;
 
 class ProtocolErrorPacket : public Packet
 {
@@ -61,12 +57,12 @@ public:
 	ProtocolErrorPacket();
 	ProtocolErrorPacket( UT_sint32 errorEnum );
 	DECLARE_PACKET(ProtocolErrorPacket);
-	
+
 	virtual UT_sint32						getProtocolVersion() const
 		{ return 0; } // not ABICOLLAB_PROTOCOL_VERSION!!
 	UT_sint32 								getErrorEnum() const
 		{ return m_errorEnum; }
-	UT_sint32								getRemoteVersion() const	
+	UT_sint32								getRemoteVersion() const
 		{ return m_remoteVersion; }
 protected:
 	UT_sint32		m_errorEnum;
@@ -83,12 +79,13 @@ public:
 	static UT_UTF8String					getStaticStorageType()
 		{ /* every backend should re-implement this static function */ return "null"; };
 	virtual UT_UTF8String					getStorageType() = 0;
-	virtual UT_UTF8String					getDescription() = 0;	
+	virtual UT_UTF8String					getDescription() = 0;
 	virtual UT_UTF8String					getDisplayType() = 0;
-	
-	void									addProperty(const string& key, const string& value)
+
+	void									addProperty(const std::string& key, const std::string& value)
 		{ m_properties[key] = value; }
-	const string							getProperty(const string& key);
+	bool									hasProperty(const std::string& key);
+	const std::string							getProperty(const std::string& key);
 	PropertyMap&							getProperties()
 		{ return m_properties; }
 
@@ -96,8 +93,13 @@ public:
 	virtual UT_UTF8String					getShareHint(PD_Document* /*pDoc*/) { return ""; }
 	virtual void							embedDialogWidgets(void* pEmbeddingParent) = 0;
 	virtual void							removeDialogWidgets(void* pEmbeddingParent) = 0;
+	virtual bool							canDelete()
+		{ return true; }
+	virtual bool							canEditProperties()
+		{ return true; }
+	virtual void							loadProperties() = 0;
 	virtual void							storeProperties() = 0;
-	
+
 	#ifdef WIN32
 	virtual BOOL							_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam) = 0;
 	virtual bool							shouldProcessFocus() = 0;
@@ -108,14 +110,14 @@ public:
 	virtual bool							disconnect() = 0;
 	virtual bool							isOnline() = 0;
 	virtual bool							autoConnect();
-	
+
 	// for duplicate prevention
 	virtual bool							operator==(AccountHandler & rhHandler);
 
 	// packet management
 	virtual bool							send(const Packet* packet) = 0;
 	virtual bool							send(const Packet* packet, BuddyPtr buddy) = 0;
-	
+
 	// user management
 	void									addBuddy(BuddyPtr pBuddy);
 	std::vector<BuddyPtr>&					getBuddies()
@@ -126,9 +128,9 @@ public:
 	virtual BuddyPtr						constructBuddy(const PropertyMap& vProps) = 0;
 	// Constructs a buddy given a buddy descriptor
 	// NOTE: some backends require additional *backend specific* session information
-	// to construct a particular buddy. Information that is not available in the buddy 
+	// to construct a particular buddy. Information that is not available in the buddy
 	// descriptor (the service and sugar backends need this for example)
-	// This additional information can then be retrieved via the 'pBuddy' 
+	// This additional information can then be retrieved via the 'pBuddy'
 	// argument. That means that the pBuddy should already be in a session and
 	// thus have access to all backend specific session information
 	virtual BuddyPtr						constructBuddy(const std::string& descriptor, BuddyPtr pBuddy) = 0;
@@ -140,6 +142,8 @@ public:
 	// Return true if you can to share a file with this buddy, false otherwise
 	virtual bool							canShare(BuddyPtr /*pBuddy*/)
 		{ return true; }
+	virtual bool							defaultShareState(BuddyPtr /*pBuddy*/)
+		{ return false; }
 
 	// session management
 	virtual void							getSessionsAsync();
@@ -165,7 +169,7 @@ public:
 
 	// signal management
 	virtual void							signal(const Event& event, BuddyPtr pSource);
-	
+
 	// protocol error management
 	enum
 	{
@@ -178,7 +182,7 @@ protected:
 	void 									_createPacketStream(std::string& sString, const Packet* pPacket);	// creates binary string!
 	virtual bool							_handleProtocolError(Packet* packet, BuddyPtr buddy);
 	virtual	void							_handlePacket(Packet* packet, BuddyPtr buddy);
-	
+
 	// protocol error management
 	void									_sendProtocolError(BuddyPtr, UT_sint32 errorEnum);
 
