@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <string>
@@ -487,7 +487,7 @@ std::string Glob_ChangeRecordSessionPacket::toStr() const
 GlobSessionPacket::GlobSessionPacket( const GlobSessionPacket& Other )
 : AbstractChangeRecordSessionPacket( Other )
 {
-	UT_DEBUGMSG(("GlobSessionPacket::GlobSessionPacket: copying %u sub packets\n", Other.m_pPackets.size()));
+	UT_DEBUGMSG(("GlobSessionPacket::GlobSessionPacket: copying %lu sub packets\n", Other.m_pPackets.size()));
 	m_pPackets.resize( Other.m_pPackets.size() );
 	for (size_t i=0; i<Other.m_pPackets.size(); ++i) {
 		m_pPackets[i] = static_cast<SessionPacket*>( Other.m_pPackets[i]->clone() );
