@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #include <string>
@@ -277,6 +277,11 @@ void AbiCollab::setAcl(const std::vector<std::string> vAcl)
 	m_vAcl = vAcl;
 }
 
+void AbiCollab::appendAcl(const std::string& sBuddyDescriptor)
+{
+	m_vAcl.push_back(sBuddyDescriptor);
+}
+
 void AbiCollab::_setDocument(PD_Document* pDoc)
 {
 	UT_DEBUGMSG(("AbiCollab::setDocument()\n"));
@@ -369,7 +374,7 @@ void AbiCollab::push(SessionPacket* pPacket)
 		m_pRecorder->storeOutgoing( const_cast<const SessionPacket*>( pPacket ) );
 		
 	// TODO: this could go in the session manager
-	UT_DEBUGMSG(("Pusing packet to %d collaborators\n", m_vCollaborators.size()));
+	UT_DEBUGMSG(("Pusing packet to %lu collaborators\n", (long unsigned)m_vCollaborators.size()));
 	for (std::map<BuddyPtr, std::string>::iterator it = m_vCollaborators.begin(); it != m_vCollaborators.end(); it++)
 	{
 		BuddyPtr pCollaborator = (*it).first;
@@ -488,7 +493,7 @@ void AbiCollab::import(SessionPacket* pPacket, BuddyPtr collaborator)
 	
 	if (isLocallyControlled() && maskedPackets.size() > 0)
 	{
-		UT_DEBUGMSG(("Forwarding message (%u packets) from %s\n", maskedPackets.size(), collaborator->getDescription().utf8_str()));
+		UT_DEBUGMSG(("Forwarding message (%lu packets) from %s\n", (long unsigned)maskedPackets.size(), collaborator->getDescription().utf8_str()));
 		
 		// It seems we are in the center of a collaboration session.
 		// It's our duty to reroute the packets to the other collaborators
@@ -547,7 +552,9 @@ void AbiCollab::initiateSessionTakeover(BuddyPtr pNewMaster)
 	m_mAckedSessionTakeoverBuddies.clear();
 	m_bSessionFlushed = false;
 	if (m_vOutgoingQueue.size() > 0)
+	{
 		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+	}
 	m_vOutgoingQueue.clear();
 
 	// send a SessionTakeoverRequest packet to the new master
@@ -983,7 +990,7 @@ void AbiCollab::_restartAsMaster()
 
 void AbiCollab::_pushOutgoingQueue()
 {
-	UT_DEBUGMSG(("AbiCollab::_pushOutgoingQueue() - %d packets queued\n", m_vOutgoingQueue.size()));
+	UT_DEBUGMSG(("AbiCollab::_pushOutgoingQueue() - %lu packets queued\n", (long unsigned)m_vOutgoingQueue.size()));
 
 	for (std::vector<SessionPacket*>::iterator it = m_vOutgoingQueue.begin(); it != m_vOutgoingQueue.end(); it++)
 		push(*it);
