@@ -42,6 +42,9 @@
 #include <goffice/component/go-component-factory.h>
 #include <goffice/goffice.h>
 #include <gsf/gsf-libxml.h>
+#ifndef G_VALUE_INIT
+#define G_VALUE_INIT { 0, { { 0 } } }
+#endif
 
 static void changed_cb (GOComponent*, gpointer);
 
@@ -277,6 +280,8 @@ AbiGOComponent_Create (G_GNUC_UNUSED AV_View* v, G_GNUC_UNUSED EV_EditMethodCall
 		gtk_tree_selection_get_selected (sel, NULL, &iter)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (list), &iter, 1, &mime_type, -1);
 		GOComponent *component = go_component_new_by_mime_type (mime_type);
+		go_component_set_inline (component, true);
+		go_component_set_use_font_from_app (component, true);
 		g_signal_connect (G_OBJECT (component), "changed",
 								G_CALLBACK (changed_cb), NULL);
 		GtkWindow *win = go_component_edit(component);
@@ -297,15 +302,13 @@ GR_AbiGOComponentItems::~GR_AbiGOComponentItems(void)
 }
 
 
-GR_GOComponentManager::GR_GOComponentManager(GR_Graphics* pG, char const *mime_type)
+GR_GOComponentManager::GR_GOComponentManager(GR_Graphics* pG)
   : GR_EmbedManager(pG), 
     m_CurrentUID(-1),
-    m_pDoc(NULL),
-	m_MimeType(mime_type)
+    m_pDoc(NULL)
 {
   m_vecGOComponentView.clear();
   m_vecItems.clear();
-	m_ObjectType = UT_String ("GOComponent//") + mime_type;
 }
 
 GR_GOComponentManager::~GR_GOComponentManager()
@@ -316,27 +319,12 @@ GR_GOComponentManager::~GR_GOComponentManager()
 
 GR_EmbedManager * GR_GOComponentManager::create(GR_Graphics * pG)
 {
-  return static_cast<GR_EmbedManager *>(new GR_GOComponentManager(pG, m_MimeType));
+  return static_cast<GR_EmbedManager *>(new GR_GOComponentManager(pG));
 }
 
 const char * GR_GOComponentManager::getObjectType(void) const
 {
-  return m_ObjectType.c_str ();
-}
-
-const char * GR_GOComponentManager::getMimeType(void) const
-{
-	return m_MimeType;
-}
-
-const char * GR_GOComponentManager::getMimeTypeDescription(void) const
-{
-	return go_mime_type_get_description (m_MimeType);
-}
-
-const char * GR_GOComponentManager::getMimeTypeSuffix(void) const
-{
-	return go_components_get_mime_suffix (m_MimeType);
+  return "GOComponent";
 }
 
 void GR_GOComponentManager::initialize(void)
@@ -526,6 +514,12 @@ void GR_GOComponentManager::setRun(UT_sint32 uid, fp_Run *pRun)
 	pGOComponentView->SetRun (pRun);
 }
 
+bool GR_GOComponentManager::setFont(UT_sint32 uid, const GR_Font * pFont)
+{
+	GOComponentView * pGOComponentView = m_vecGOComponentView.getNthItem(uid);
+	return pGOComponentView->setFont (pFont);
+}
+
 void GR_GOComponentManager:: updateData(UT_sint32 uid, UT_sint32 api)
 {
 	GR_AbiGOComponentItems * pItem = m_vecItems.getNthItem(uid);
@@ -599,10 +593,10 @@ changed_cb (GOComponent *component, gpointer data)
 			if (buf && length) {
 				UT_ByteBuf myByteBuf;
 				myByteBuf.append (buf, length);
-				UT_String Props=UT_String ("embed-type: GOComponent//") + component->mime_type;
+				UT_String Props="embed-type: GOComponent";
 				guint i, nbprops;
 				GType    prop_type;
-				GValue	 value = {0, {{0}, {0}}};
+				GValue	 value = G_VALUE_INIT;
 				char *prop = NULL;
 				GParamSpec **specs = g_object_class_list_properties (
 							G_OBJECT_GET_CLASS (component), &nbprops);
@@ -667,6 +661,8 @@ void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, const char
 		component = go_component_new_by_mime_type (_mime_type);
 	}
 	UT_return_if_fail (component);
+	go_component_set_inline (component, true);
+	go_component_set_use_font_from_app (component, true);
 	g_signal_connect (G_OBJECT (component), "changed",
 								G_CALLBACK (changed_cb), this);
 	if (component == NULL) {
@@ -679,7 +675,7 @@ void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, const char
 			PP_AttrProp const *Props = m_pRun->getSpanAP ();
 			GParamSpec *prop_spec;
 			int i = 0;
-			GValue res = {0,{{0},{0}}};
+			GValue res = G_VALUE_INIT;
 			gchar const *szName, *szValue;
 			while (Props->getNthProperty (i++, szName, szValue)) {
 				prop_spec = g_object_class_find_property (
@@ -706,11 +702,18 @@ void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, const char
 	descent =  (UT_sint32) rint (_descent * UT_LAYOUT_RESOLUTION);
 }
 
-
-void GOComponentView::setDefaultFontSize(G_GNUC_UNUSED UT_sint32 iSize)
+void GOComponentView::setDefaultFontSize(UT_sint32 /*iSize*/)
 {
 }
 
+bool GOComponentView::setFont(const GR_Font * pFont)
+{
+	UT_return_val_if_fail(component && pFont, false);
+	const GR_PangoFont *pPF = dynamic_cast<const GR_PangoFont *>(pFont);
+	UT_return_val_if_fail(pPF, false);
+	return go_component_set_font(component, pPF->getPangoDescription());
+}
+
 void GOComponentView::modify()
 {
 	UT_return_if_fail (component);
@@ -729,10 +732,11 @@ void GOComponentView::update ()
 		if (buf && length) {
 		UT_ByteBuf myByteBuf;
 		myByteBuf.append (buf, length);
-		UT_String Props=UT_String ("embed-type: GOComponent//") + mime_type;
+		mime_type = component->mime_type;
+		UT_String Props="embed-type: GOComponent";
 		guint i, nbprops;
 		GType    prop_type;
-		GValue	 value = {0, {{0}, {0}}};
+		GValue	 value = G_VALUE_INIT;
 		char *prop = NULL;
 		GParamSpec **specs = g_object_class_list_properties (
 					G_OBJECT_GET_CLASS (component), &nbprops);
@@ -752,7 +756,7 @@ void GOComponentView::update ()
 					case G_TYPE_ULONG:
 					case G_TYPE_FLOAT:
 					case G_TYPE_DOUBLE: {
-						GValue str;
+						GValue str = G_VALUE_INIT;
 						g_value_init (&str, G_TYPE_STRING);
 						g_value_transform (&value, &str);
 						prop = g_strdup (g_value_get_string (&str));
@@ -777,7 +781,7 @@ void GOComponentView::update ()
 				}
 			}
 		}
-		pView->cmdUpdateEmbed(m_pRun, &myByteBuf,mime_type.c_str(),Props.c_str());
+		pView->cmdUpdateEmbed(m_pRun, &myByteBuf,mime_type.c_str(), Props.c_str());
 		} else
 			pView->cmdDeleteEmbed(m_pRun);
 		if (clearfunc)
