@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifdef ABI_PLUGIN_BUILTIN
@@ -28,19 +28,7 @@
 #include "config.h"
 #endif
 
-#include <MathView/Init.hh>
-#include <MathView/MathMLElement.hh>
-#include <MathView/ShaperManager.hh>
-#include <MathView/SpaceShaper.hh>
-#include <MathView/libxml2_MathView.hh>
-#include <MathView/MathMLElement.hh>
-#include <MathView/Logger.hh>
-#include <MathView/AbstractLogger.hh>
-#include <MathView/BoundingBox.hh>
-#include <MathView/MathMLNamespaceContext.hh>
-#include <MathView/NamespaceContext.hh>
-#include <MathView/MathMLElement.hh>
-#include <MathView/MathMLOperatorDictionary.hh>
+#include "mathview_proxy.h"
 #include "gr_Abi_MathGraphicDevice.h"
 #include "gr_Abi_RenderingContext.h"
 
@@ -82,6 +70,7 @@
 #include "ap_Dialog_Latex.h"
 #include "ut_mbtowc.h"
 #include "ap_Menu_Id.h"
+#include "ie_math_convert.h"
 
 #include "ut_sleep.h"
 #include <sys/types.h>  
@@ -461,20 +450,34 @@ AbiMathView_FileInsert(AV_View* /*v*/, EV_EditMethodCallData* /*d*/)
 		DELETEP(pImpMathML);
 		return false;
 	}
+	
+	UT_UTF8String PbMathml = (const char*)((pImpMathML->getByteBuf())->getPointer(0));
+	UT_UTF8String PbLatex;
+	UT_UTF8String Pbitex;
 
-	/* Create the data item */
-	UT_uint32 uid = pDoc->getUID(UT_UniqueId::Image);
-	UT_UTF8String sUID;
-	UT_UTF8String_sprintf(sUID,"%d",uid);
-	pDoc->createDataItem(sUID.utf8_str(), false, pImpMathML->getByteBuf(), 
-                         "application/mathml+xml", NULL);
+	if(convertMathMLtoLaTeX(PbMathml, PbLatex) && convertLaTeXtoEqn(PbLatex,Pbitex))
+	{
+		// Conversion of MathML to LaTeX and the Equation Form suceeds
+		pView->cmdInsertLatexMath(Pbitex,PbMathml);
+	}
+	else
+	{
+		// Conversion of MathML to LaTeX fails
+		// Inserting only the MathML
 
-	/* Insert the MathML Object */
-	PT_DocPosition pos = pView->getPoint();
-	pView->cmdInsertMathML(sUID.utf8_str(),pos);
+		/* Create the data item */
+		UT_uint32 uid = pDoc->getUID(UT_UniqueId::Image);
+		UT_UTF8String sUID;
+		UT_UTF8String_sprintf(sUID,"%d",uid);
+		pDoc->createDataItem(sUID.utf8_str(), false, pImpMathML->getByteBuf(), 
+		                     "application/mathml+xml", NULL); 
+
+		/* Insert the MathML Object */
+		PT_DocPosition pos = pView->getPoint();
+		pView->cmdInsertMathML(sUID.utf8_str(),pos); 
+	}
 
 	DELETEP(pImpMathML);
-
 	return true;
 }
 
@@ -703,7 +706,7 @@ void GR_MathManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
 {
 	const PP_AttrProp * pSpanAP = NULL;
 	const char * pszDataID = NULL;
-	bool bFoundDataID = false;
+	UT_DebugOnly<bool> bFoundDataID = false;
 
 	if (!getGraphics()->queryProperties(GR_Graphics::DGP_SCREEN))
 	{
@@ -716,7 +719,7 @@ void GR_MathManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
 	m_pDoc->getAttrProp(api, &pSpanAP);
 
 	bFoundDataID = pSpanAP->getAttribute("dataid", pszDataID);
-	UT_ASSERT((bFoundDataID));
+	UT_ASSERT(bFoundDataID);
 
 	if (pItem->m_bHasSnapshot)
 	{
@@ -941,7 +944,7 @@ bool GR_MathManager::convert(UT_uint32 iConType, UT_ByteBuf & From, UT_ByteBuf &
 	return EntityTable().convert(sMathML.utf8_str(), sMathML.size(), To);
 }
 
-static UT_uint32 MathManagerUID = 0; 
+//static UT_uint32 MathManagerUID = 0; 
 
 ABI_PLUGIN_DECLARE(AbiMathView)
 
@@ -963,7 +966,7 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	// Add to AbiWord's plugin listeners
 	XAP_App * pApp = XAP_App::getApp();	
 	pMathManager = new GR_MathManager(NULL);
-	MathManagerUID = pApp->registerEmbeddable(pMathManager);
+	pApp->registerEmbeddable(pMathManager);
 
 	// Add to AbiWord's menus
 	AbiMathView_addToMenus();
@@ -981,7 +984,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	mi->usage = 0;
 
 	XAP_App * pApp = XAP_App::getApp();
-	pApp->unRegisterEmbeddable(MathManagerUID);
+	pApp->unRegisterEmbeddable(pMathManager->getObjectType());
 	DELETEP(pMathManager);
 	AbiMathView_removeFromMenus();
 
