@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 
@@ -22,6 +22,7 @@
 #include <string.h>
 
 #include "ut_string.h"
+#include "ut_std_string.h"
 #include "ut_bytebuf.h"
 #include "ut_base64.h"
 #include "ut_locale.h"
@@ -434,7 +435,7 @@ void s_WML_Listener::_emitTOC (PT_AttrPropIndex api) {
 	bool bHaveProp = (api ? (m_pDocument->getAttrProp (api, &pAP)) : false);
 	bool bEmitHeading = true;
 	const gchar * szValue = 0;
-	UT_UTF8String tocHeadingUTF8;
+	std::string tocHeadingUTF8;
 
 	_closeSpan();
 	_closeBlock();
@@ -460,7 +461,7 @@ void s_WML_Listener::_emitTOC (PT_AttrPropIndex api) {
 
 		//TODO: query the style properties to determine whether to center the TOC heading
 		m_pie->write("<p>");
-		m_pie->write(tocHeadingUTF8.escapeXML().utf8_str());
+		m_pie->write(UT_escapeXML(tocHeadingUTF8));
 		m_pie->write("</p>\n");
 	}
 
@@ -502,7 +503,7 @@ void s_WML_Listener::_emitTOC (PT_AttrPropIndex api) {
 /*****************************************************************/
 /*****************************************************************/
 
-bool s_WML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
+bool s_WML_Listener::populate(fl_ContainerLayout* /*sfh*/,
 				 const PX_ChangeRecord * pcr)
 {
 	switch (pcr->getType())
@@ -588,9 +589,9 @@ bool s_WML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 	}
 }
 
-bool s_WML_Listener::populateStrux(PL_StruxDocHandle sdh,
+bool s_WML_Listener::populateStrux(pf_Frag_Strux* sdh,
 				      const PX_ChangeRecord * pcr,
-				      PL_StruxFmtHandle * psfh)
+				      fl_ContainerLayout* * psfh)
 {
 	UT_ASSERT_HARMLESS(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
 	const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
@@ -704,20 +705,20 @@ bool s_WML_Listener::populateStrux(PL_StruxDocHandle sdh,
 	}
 }
 
-bool s_WML_Listener::change(PL_StruxFmtHandle /*sfh*/,
+bool s_WML_Listener::change(fl_ContainerLayout* /*sfh*/,
 			       const PX_ChangeRecord * /*pcr*/)
 {
   UT_ASSERT_NOT_REACHED();	    // this function is not used.
   return false;
 }
 
-bool s_WML_Listener::insertStrux(PL_StruxFmtHandle /*sfh*/,
+bool s_WML_Listener::insertStrux(fl_ContainerLayout* /*sfh*/,
 				     const PX_ChangeRecord * /*pcr*/,
-				     PL_StruxDocHandle /*sdh*/,
+				     pf_Frag_Strux* /*sdh*/,
 				     PL_ListenerId /* lid */,
-				     void (* /*pfnBindHandles*/)(PL_StruxDocHandle /* sdhNew */,
+				     void (* /*pfnBindHandles*/)(pf_Frag_Strux* /* sdhNew */,
 								 PL_ListenerId /* lid */,
-																 PL_StruxFmtHandle /* sfhNew */))
+																 fl_ContainerLayout* /* sfhNew */))
 {
   UT_ASSERT_NOT_REACHED();	    // this function is not used.
   return false;
@@ -734,13 +735,13 @@ bool s_WML_Listener::signal(UT_uint32 /* iSignal */)
 
 void s_WML_Listener::_handleMetaData()
 {
-	UT_UTF8String metaProp("");
+	std::string metaProp;
 	m_pie->write("<head>\n");
 
 	#define WRITEMETA(name)\
-		metaProp.escapeXML();\
+		metaProp = UT_escapeXML(metaProp);\
 		if(metaProp.length())\
-			m_pie->write(UT_UTF8String_sprintf("<meta name=\"%s\" content=\"%s\"/>\n", name, metaProp.utf8_str()).utf8_str());\
+		  m_pie->write(UT_std_string_sprintf("<meta name=\"%s\" content=\"%s\"/>\n", name, metaProp.c_str()).c_str()); \
 
 	if (m_pDocument->getMetaDataProp (PD_META_KEY_TITLE, metaProp) && metaProp.size())
 	{
