@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #define WIN32_LEAN_AND_MEAN
@@ -366,7 +366,7 @@ LRESULT CALLBACK EV_Win32Toolbar::_ComboWndProc( HWND hWnd, UINT uMessage, WPARA
                 ExtTextOutW(dis->hDC, dis->rcItem.left, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, str.c_str(), str.size(), 0);
 				
 				/*Font example after the name*/
-				wchar_t* szSample = L"AbCdEfGhIj";
+				const wchar_t* szSample = L"AbCdEfGhIj";
                 GetTextExtentPoint32W(dis->hDC, str.c_str(), str.size(), &size);
 				SelectObject (dis->hDC, hFont);
 				ExtTextOutW(dis->hDC, dis->rcItem.left+size.cx+5, dis->rcItem.top, ETO_OPAQUE | ETO_CLIPPED, 0, szSample, wcslen(szSample), 0);
@@ -807,8 +807,8 @@ bool EV_Win32Toolbar::synthesize(void)
 					if (bIcons)
 					{
 						HBITMAP hBitmap;
-						const bool bFoundIcon =
-							AP_Win32Toolbar_Icons::getBitmapForIcon(m_hwnd,
+						UT_DebugOnly<bool> bFoundIcon =
+							XAP_Win32Toolbar_Icons::getBitmapForIcon(m_hwnd,
 																	MY_MAXIMUM_BITMAP_X,
 																	MY_MAXIMUM_BITMAP_Y,
 																	&backgroundColor,
@@ -968,7 +968,7 @@ bool EV_Win32Toolbar::bindListenerToView(AV_View * pView)
 	m_pViewListener = new EV_Win32Toolbar_ViewListener(this,pView);
 	UT_ASSERT(m_pViewListener);
 
-	bool bResult = pView->addListener(static_cast<AV_Listener *>(m_pViewListener),&m_lid);
+	UT_DebugOnly<bool> bResult = pView->addListener(static_cast<AV_Listener *>(m_pViewListener),&m_lid);
 	UT_ASSERT(bResult);
 
 	if(pView->isDocumentPresent())
@@ -1083,7 +1083,7 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 				//bool bString = EV_TIS_ShouldUseString(tis);
 				HWND hwndCombo = _getControlWindow(id);
 				UT_return_val_if_fail(hwndCombo, true);
-				UT_UTF8String utf8;
+				std::string utf8;
 				UT_String str;
 				
 				// NOTE: we always update the control even if !szState
@@ -1100,14 +1100,14 @@ bool EV_Win32Toolbar::_refreshItem(AV_View * pView, const EV_Toolbar_Action * pA
 				if (id==AP_TOOLBAR_ID_FMT_STYLE)
 				{
                         pt_PieceTable::s_getLocalisedStyleName(szState, utf8);
-						localised.fromUTF8 (utf8.utf8_str());
+						localised.fromUTF8 (utf8.c_str());
                 }       
                  else
     					localised.fromUTF8 (szState);
 					
                 int idx = SendMessageW(hwndCombo, CB_FINDSTRINGEXACT, (WPARAM)-1, (LPARAM)localised.c_str());
 				if (idx!=CB_ERR)
-					SendMessageW(hwndCombo, CB_SETCURSEL, idx, NULL);
+					SendMessageW(hwndCombo, CB_SETCURSEL, idx, 0);
 				/*
 				 * If the string didn't exist within the combos list, we handle things differently for
 				 * different combos.
@@ -1216,9 +1216,9 @@ bool EV_Win32Toolbar::getToolTip(LPARAM lParam)
 void EV_Win32Toolbar::show(void)
 {
 	UT_return_if_fail(m_pWin32Frame);
-	HWND hRebar = static_cast<XAP_Win32FrameImpl*>(m_pWin32Frame->getFrameImpl())->getToolbarWindow();
+	UT_DebugOnly<HWND> hRebar = static_cast<XAP_Win32FrameImpl*>(m_pWin32Frame->getFrameImpl())->getToolbarWindow();
 	UT_ASSERT(hRebar);
-	const int iBand = _getBandForHwnd(m_hwnd);
+	UT_DebugOnly<int> iBand = _getBandForHwnd(m_hwnd);
 	UT_ASSERT(iBand < 0);	// It can't already be displayed!
 	_addToRebar();
 
@@ -1374,7 +1374,7 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 // Now make a new one.
 //
 	int	nItem;													    
-	UT_UTF8String utf8;
+	std::string utf8;
 	UT_String str;
 
 	for (UT_sint32 c=0; c < m_vecOrgStylesNames.getItemCount(); c++)	
@@ -1389,7 +1389,7 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 		UT_Win32LocaleString localised;
 		
 		pt_PieceTable::s_getLocalisedStyleName(sz, utf8);
-		localised.fromUTF8 (utf8.utf8_str());
+		localised.fromUTF8 (utf8.c_str());
 		
 		nItem = SendMessageW(hwndCombo, CB_ADDSTRING,(WPARAM)0, (LPARAM)localised.c_str());
 		m_vecOrgStylesNames.addItem (new UT_UTF8String ((char *)v->getNthItem(k)));
