@@ -1,21 +1,21 @@
-/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /* AbiWord
  * Copyright (C) 2004-2006 Tomas Frydrych <dr.tomas@yahoo.co.uk>
- * Copyright (C) 2009 Hubert Figuiere
- * 
+ * Copyright (C) 2009-2016 Hubert Figuiere
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  * 02110-1301 USA.
  */
 
@@ -28,6 +28,9 @@
 
 #include "xap_App.h"
 #include "xap_EncodingManager.h"
+#if GTK_CHECK_VERSION(3,0,0)
+#include "xap_GtkStyle.h"
+#endif
 
 GR_UnixCairoGraphicsBase::~GR_UnixCairoGraphicsBase()
 {
@@ -79,7 +82,13 @@ GR_UnixCairoGraphics::GR_UnixCairoGraphics(GdkWindow * win, bool double_buffered
 	  m_Painting(false),
 	  m_Signal(0),
  	  m_DestroySignal(0),
-     m_Widget(NULL)
+#if GTK_CHECK_VERSION(3,0,0)
+	  m_Widget(NULL),
+	  m_styleBg(NULL),
+	  m_styleHighlight(NULL)
+#else
+	  m_Widget(NULL)
+#endif
 {
 	m_cr = NULL;
 	if (_getWindow())
@@ -99,6 +108,14 @@ GR_UnixCairoGraphics::~GR_UnixCairoGraphics()
 		g_signal_handler_disconnect (m_Widget, m_Signal);
 		g_signal_handler_disconnect (m_Widget, m_DestroySignal);
 	}
+#if GTK_CHECK_VERSION(3,0,0)
+	if (m_styleBg) {
+		g_object_unref(m_styleBg);
+	}
+	if (m_styleHighlight) {
+		g_object_unref(m_styleHighlight);
+	}
+#endif
 }
 
 
@@ -160,36 +177,38 @@ void GR_UnixCairoGraphics::initWidget(GtkWidget* widget)
 #define SQUARE(A) (A)*(A)
 void GR_UnixCairoGraphics::init3dColors(GtkWidget* /*w*/)
 {
-	GtkStyleContext* pCtxt = gtk_style_context_new();
-	GtkWidgetPath *path = gtk_widget_path_new();
-	gtk_widget_path_append_type(path, GTK_TYPE_TEXT_VIEW);
-	gtk_style_context_set_path(pCtxt, path);
-	gtk_widget_path_free(path);
-
-	GdkRGBA rgba1, rgba2, rgba_;
-	bool bUseThemeColors = true;
-
-	gtk_style_context_save(pCtxt);
-	gtk_style_context_add_class(pCtxt, GTK_STYLE_CLASS_BUTTON);
-
-	gtk_style_context_get_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba1);
-	gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_NORMAL, &rgba2);
-	if ((SQUARE(rgba1.red-rgba2.red) + SQUARE(rgba1.green-rgba2.green) + SQUARE(rgba1.blue - rgba2.blue)) < 0.01)
-	{
-		// There is very little contrast between the bg and fg colors
-		// Use default values (black for fg and white for bg)
-		// This happens for unknown reasons with some themes
-		UT_DEBUGMSG(("No contrast between the theme foreground and background colors! Use black and white instead.\n"));
-		bUseThemeColors = false;
-		rgba1.red = 0.;
-		rgba1.green = 0.;
-		rgba1.blue = 0.;
-		rgba2.red = 1.;
-		rgba2.green = 1.;
-		rgba2.blue = 1.;
+	if (m_styleBg) {
+		g_object_unref(m_styleBg);
 	}
-	m_3dColors[CLR3D_Foreground] = _convertGdkRGBA(rgba1);
+	m_styleBg = XAP_GtkStyle_get_style(nullptr, "GtkButton"); // "button"
+	// guess colours
+	// WHITE
+	GdkRGBA rgba2;
+	rgba2.red = 1.;
+	rgba2.green = 1.;
+	rgba2.blue = 1.;
+	rgba2.alpha = 1;
+	// this is the colour used notably for the the ruler.
+	// Gray-ish in adwaita, black in Dark theme
 	m_3dColors[CLR3D_Background] = _convertGdkRGBA(rgba2);
+
+	// this is white in Adwaita, and black in a dark theme.
+	GdkRGBA rgba1;
+	if (m_styleHighlight) {
+		g_object_unref(m_styleHighlight);
+	}
+	m_styleHighlight = XAP_GtkStyle_get_style(NULL, "GtkTreeView.view"); // "textview.view"
+	gtk_style_context_get_color (m_styleHighlight, GTK_STATE_FLAG_NORMAL, &rgba1);
+	m_3dColors[CLR3D_Highlight] = _convertGdkRGBA(rgba1);
+
+	// guess colours.
+	// BLACK
+	rgba1.red = 0.;
+	rgba1.green = 0.;
+	rgba1.blue = 0.;
+	rgba1.alpha = 1;
+
+	GdkRGBA rgba_;
 	rgba_.alpha = 1.;   // we don't really care, abiword does not use transparency
 	rgba_.red = rgba1.red*COLOR_MIX + rgba2.red*(1.-COLOR_MIX);
 	rgba_.green = rgba1.green*COLOR_MIX + rgba2.green*(1.-COLOR_MIX);
@@ -201,15 +220,13 @@ void GR_UnixCairoGraphics::init3dColors(GtkWidget* /*w*/)
 	rgba_.blue = rgba1.blue*(1.-COLOR_MIX) + rgba2.blue*COLOR_MIX;
 	m_3dColors[CLR3D_BevelDown]  = _convertGdkRGBA(rgba_);
 
-	if (bUseThemeColors)
-	{
-		gtk_style_context_get_background_color (pCtxt, GTK_STATE_FLAG_PRELIGHT, &rgba2);
-	}
-	gtk_style_context_restore(pCtxt);
-	m_3dColors[CLR3D_Highlight]	= _convertGdkRGBA(rgba2);
-	m_bHave3DColors = true;
 
-	g_object_unref(pCtxt);
+	GtkStyleContext *text_style = XAP_GtkStyle_get_style(NULL, "GtkLabel.view"); // "label.view"
+	gtk_style_context_get_color (text_style, GTK_STATE_FLAG_NORMAL, &rgba2);
+	m_3dColors[CLR3D_Foreground]	= _convertGdkRGBA(rgba2);
+	g_object_unref(text_style);
+
+	m_bHave3DColors = true;
 }
 #undef COLOR_MIX
 #undef SQUARE
@@ -558,6 +575,13 @@ void GR_UnixCairoGraphics::_endPaint()
 	GR_CairoGraphics::_endPaint();
 }
 
+void GR_UnixCairoGraphics::flush(void)
+{
+	if (m_Widget) {
+		gtk_widget_queue_draw(m_Widget);
+	}
+}
+
 bool GR_UnixCairoGraphics::queryProperties(GR_Graphics::Properties gp) const
 {
 	switch (gp)
@@ -573,3 +597,56 @@ bool GR_UnixCairoGraphics::queryProperties(GR_Graphics::Properties gp) const
 	}
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
+bool GR_UnixCairoGraphics::getColor3D(GR_Color3D name, UT_RGBColor &color)
+{
+	switch(name) {
+	case GR_Graphics::CLR3D_Background:
+	case GR_Graphics::CLR3D_Highlight:
+		return false;
+
+	default:
+		return GR_CairoGraphics::getColor3D(name, color);
+	}
+}
+
+/**
+ * This is an override that will use the GtkStyle code to actually render
+ * directly.
+ */
+void GR_UnixCairoGraphics::fillRect(GR_Color3D c, UT_sint32 x, UT_sint32 y,
+                                    UT_sint32 w, UT_sint32 h)
+{
+	switch(c) {
+	case GR_Graphics::CLR3D_Background:
+	case GR_Graphics::CLR3D_Highlight:
+	{
+		if (m_cr == NULL) {
+			return;
+		}
+		_setProps();
+		cairo_save (m_cr);
+
+		GtkStyleContext *context = nullptr;
+		switch(c) {
+		case GR_Graphics::CLR3D_Background:
+			context = m_styleBg;
+			break;
+		case GR_Graphics::CLR3D_Highlight:
+			context = m_styleHighlight;
+			break;
+		default:
+			UT_ASSERT(0);
+			return;
+		}
+		gtk_render_background (context, m_cr, tdu(x), tdu(y), tdu(w), tdu(h));
+		gtk_render_frame (context, m_cr, tdu(x), tdu(y), tdu(w), tdu(h));
+		cairo_restore (m_cr);
+		break;
+	}
+	default:
+		GR_CairoGraphics::fillRect(c, x, y, w, h);
+		return;
+	}
+}
+#endif
