@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,8 +34,11 @@
 #include "gr_CharWidths.h"
 #include "ut_assert.h"
 #include "ut_string.h"
+#include "ut_std_string.h"
 #include "ut_units.h"
 #include "ut_sleep.h"
+#include "ut_stack.h"
+#include "ut_std_map.h"
 #include "ut_growbuf.h"
 #include "ut_debugmsg.h"
 #include "ut_OverstrikingChars.h"
@@ -65,7 +68,7 @@ GR_Font::~GR_Font()
   Return the hash key used by the cache to fetch the font
   This method may be overridden to compute it in real time if needed
  */
-const UT_String & GR_Font::hashKey(void) const
+const std::string & GR_Font::hashKey(void) const
 {
 	return m_hashKey;
 }
@@ -234,6 +237,8 @@ GR_Graphics::GR_Graphics()
 	  m_pRect(NULL),
 	  m_bHave3DColors(false),
 	  m_paintCount(0),
+	  m_bDoubleBufferingActive(false),
+	  m_bDrawingSuspended(false),
 	  m_pCaret(NULL),
 	  m_bIsPortrait(true),
 	  m_bSpawnedRedraw(false),
@@ -243,7 +248,6 @@ GR_Graphics::GR_Graphics()
 	  m_bDoMerge(false),
 	  m_iPrevYOffset(0),
 	  m_iPrevXOffset(0),
-	  m_hashFontCache(19),
 	  m_AllCarets(this,&m_pCaret,&m_vecCarets),
 	  m_bAntiAliasAlways(false)
 {
@@ -261,11 +265,13 @@ GR_Font* GR_Graphics::findFont(const char* pszFontFamily,
 
 	// NOTE: we currently favor a readable hash key to make debugging easier
 	// TODO: speed things up with a smaller key (the three AP pointers?)
-	UT_String key;
+	std::string key = UT_std_string_sprintf("%s;%s;%s;%s;%s;%s",pszFontFamily, 
+											pszFontStyle, pszFontVariant, 
+											pszFontWeight, pszFontStretch, 
+											pszFontSize);
 
-	UT_String_sprintf(key,"%s;%s;%s;%s;%s;%s",pszFontFamily, pszFontStyle, pszFontVariant, pszFontWeight, pszFontStretch, pszFontSize);
-	GR_Font *pEntry = m_hashFontCache.pick(key.c_str());
-	if (!pEntry)
+	FontCache::const_iterator iter = m_hashFontCache.find(key);
+	if (iter == m_hashFontCache.end())
 	{
 		// TODO -- note that we currently assume font-family to be a single name,
 		// TODO -- not a list.  This is broken.
@@ -279,11 +285,11 @@ GR_Font* GR_Graphics::findFont(const char* pszFontFamily,
 		// add it to the cache
 		
 		if(pFont)
-			m_hashFontCache.insert(key.c_str(), pFont);
+			m_hashFontCache.insert(std::make_pair(key, pFont));
 	}
 	else
 	{
-		pFont = pEntry;
+		pFont = iter->second;
 	}
 	return pFont;
 }
@@ -300,9 +306,60 @@ GR_Graphics::~GR_Graphics()
 	}
 }
 
+bool GR_Graphics::beginDoubleBuffering()
+{
+	if(m_bDoubleBufferingActive) return false;
+	m_DCSwitchManagementStack.push((int)SWITCHED_TO_BUFFER);
+	_DeviceContext_SwitchToBuffer();
+	m_bDoubleBufferingActive = true;
+	return true;
+}
+
+void GR_Graphics::endDoubleBuffering(bool token)
+{
+	// check prerequisites
+	if(token == false) return;
+
+	UT_ASSERT(m_DCSwitchManagementStack.getDepth() > 0);
+	
+	UT_sint32 topMostSwitch;
+	m_DCSwitchManagementStack.viewTop(topMostSwitch);
+	UT_ASSERT(topMostSwitch == (UT_sint32)SWITCHED_TO_BUFFER);
+
+	_DeviceContext_SwitchToScreen();
+	m_DCSwitchManagementStack.pop();
+	m_bDoubleBufferingActive = false;
+}
+
+bool GR_Graphics::suspendDrawing()
+{
+	if(m_bDrawingSuspended) return false;
+	m_DCSwitchManagementStack.push((int)DRAWING_SUSPENDED);
+	_DeviceContext_SuspendDrawing();
+	m_bDrawingSuspended = true;
+	return true;
+}
+
+void GR_Graphics::resumeDrawing(bool token)
+{
+	// check prerequisites
+	if(token == false) return;
+
+	UT_ASSERT(m_DCSwitchManagementStack.getDepth() > 0);
+	
+	UT_sint32 topMostSwitch;
+	m_DCSwitchManagementStack.viewTop(topMostSwitch);
+	UT_ASSERT(topMostSwitch == (UT_sint32)DRAWING_SUSPENDED);
+
+	// take action only if the caller has the good token
+	_DeviceContext_ResumeDrawing();
+	m_DCSwitchManagementStack.pop();
+	m_bDrawingSuspended = false;
+}
+
 void GR_Graphics::_destroyFonts ()
 {
-	m_hashFontCache.purgeData();
+	UT_map_delete_all_second(m_hashFontCache);
 	m_hashFontCache.clear ();
 }
 
