@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -86,11 +86,9 @@ UT_sint32 UT_UNIXTimer::set(UT_uint32 iMilliseconds)
 	*/
 	stop();
 
-	// typeof() is an extension. might break on non gcc. 
-	iMilliseconds = std::min(iMilliseconds, 
-							   static_cast<UT_uint32>(
-								   std::numeric_limits<typeof(m_iMilliseconds)>::max()
-								   ));
+	iMilliseconds = std::min(iMilliseconds, static_cast<UT_uint32>(
+					 std::numeric_limits<millisec_t>::max()
+					 ));
 
 #ifndef TOOLKIT_COCOA
 	m_iGtkTimerId = g_timeout_add_full(0, iMilliseconds, _Timer_Proc, this, NULL);
