@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -339,8 +339,8 @@ void UT_decodeUTF8string(const gchar * pString, UT_uint32 len, UT_GrowBuf * pRes
 
    You should have received a copy of the GNU Library General Public
    License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA.  */
 
 ////////////////////////////////////////////////////////////////////////
 //
@@ -930,7 +930,7 @@ bool UT_UCS4_isSentenceSeparator(UT_UCS4Char c)
 bool UT_UCS4_isdigit(UT_UCS4Char c)
 {
 	if (c < 0x700) {
-		for (int i=0; i < G_N_ELEMENTS(digits_table); i++) {
+		for (unsigned int i=0; i < G_N_ELEMENTS(digits_table); i++) {
 			if (c < digits_table[i].low) break;
 			if (c <= digits_table[i].high)
 				return true;
