@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 
@@ -67,6 +67,8 @@ class XAP_UnixFrameImpl : public XAP_FrameImpl
 	}
 	void resetIMContext ();
 
+	virtual GtkWidget * getViewWidget (void) const = 0;
+
 private:
 	void _setGeometry ();
 
@@ -149,7 +151,11 @@ protected:
 			static gint key_press_event(GtkWidget* w, GdkEventKey* e);
 			static gint key_release_event(GtkWidget* w, GdkEventKey* e);
 			static gint delete_event(GtkWidget * w, GdkEvent * /*event*/, gpointer /*data*/);
+#if GTK_CHECK_VERSION(3,0,0)
 			static gint draw(GtkWidget * w, cairo_t * cr);
+#else
+			static gint expose(GtkWidget * w, GdkEventExpose* pExposeEvent);
+#endif
 			static gint do_ZoomUpdate( gpointer /* xap_UnixFrame * */ p);
 			static void vScrollChanged(GtkAdjustment * w, gpointer /*data*/);
 			static void hScrollChanged(GtkAdjustment * w, gpointer /*data*/);
