@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 /*****************************************************************
@@ -380,9 +380,11 @@ dcl(LANG_HR_HR,								"Croatian")
 dcl(LANG_CS_CZ, 							"Czech")
 dcl(LANG_DA_DK, 							"Danish")
 dcl(LANG_FA_AF, 							"Dari")
+dcl(LANG_DV_MV, 							"Dhivehi")
 dcl(LANG_NL_NL, 							"Dutch")
 dcl(LANG_EN_AU, 							"English (Australia)")
 dcl(LANG_EN_CA, 							"English (Canada)")
+dcl(LANG_EN_IN, 							"English (India)")
 dcl(LANG_EN_IE, 							"English (Ireland)")
 dcl(LANG_EN_NZ, 							"English (New Zealand)")
 dcl(LANG_EN_ZA, 							"English (South Africa)")
