@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 
@@ -296,9 +296,9 @@ public:
 	bool                    sendChangeAuthorCR(pp_Author * pAuthor);
 	UT_sint32               findFirstFreeAuthorInt(void) const;
  private:
-	bool                    addAuthorAttributeIfBlank(const gchar ** szAttsIn, const gchar **& szAttsOut, UT_String & storage);
+	bool                    addAuthorAttributeIfBlank(const gchar ** szAttsIn, const gchar **& szAttsOut, std::string& storage);
 	bool                    addAuthorAttributeIfBlank( PP_AttrProp *&p_AttrProp);
-	bool                    _buildAuthorProps(pp_Author * pAuthor, const gchar **& szProps);
+	bool                    _buildAuthorProps(pp_Author * pAuthor, const gchar **& szProps, std::string& storage);
  public:
 	//
 	void					beginUserAtomicGlob(void);
@@ -527,7 +527,7 @@ PT_AttrPropIndex            getAPIFromSOH(pf_Frag_Object* odh);
 	bool					enumStyles(UT_uint32 k,
 									   const char ** pszName, const PD_Style ** ppStyle) const;
 	bool                    enumStyles(UT_GenericVector<PD_Style*> * & pStyles) const;
-
+	bool					getStyleProperty(const gchar * szStyleName, const gchar * szPropertyName, const gchar *& szPropertyValue);
 	bool					addStyleProperty(const gchar * szStyleName, const gchar * szPropertyName, const gchar * szPropertyValue);
 	bool					addStyleProperties(const gchar * szStyleName, const gchar ** pProperties);
 	bool	                setAllStyleAttributes(const gchar * szStyleName, const gchar ** pAttribs);
@@ -557,6 +557,8 @@ PT_AttrPropIndex            getAPIFromSOH(pf_Frag_Object* odh);
 	bool                    isFootnoteAtPos(PT_DocPosition pos);
 	bool                    isEndFootnoteAtPos(PT_DocPosition pos);
 	UT_sint32               getEmbeddedOffset(pf_Frag_Strux* sdh,PT_DocPosition posOff, pf_Frag_Strux* & sdhEmbedded);
+	bool                    hasEmbedStruxOfTypeInRange(PT_DocPosition posStart, PT_DocPosition posEnd, 
+													   PTStruxType iType) const;
 
 	// TOC functions
 	bool                    isTOCAtPos(PT_DocPosition pos);
