@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 
@@ -83,10 +83,7 @@ pf_Fragments::Node::~Node(void)
 //////////////////////////////////////////////
 
 pf_Fragments::pf_Fragments()
-	: m_pFirst(0),
-	  m_pLast(0),
-	  m_pCache(0),
-	  m_pLeaf(new Node(Node::black)),
+	: m_pLeaf(new Node(Node::black)),
 	  m_pRoot(m_pLeaf),
 	  m_nSize(0),
 	  m_nDocumentSize(0)
@@ -101,16 +98,14 @@ pf_Fragments::~pf_Fragments()
 		delete_tree(m_pRoot);
 
 	delete m_pLeaf;
+}
 
-	//Comment this out later.
-	while (m_pFirst)
-	{
-		pf_Frag* pNext = m_pFirst->getNext();
-		delete m_pFirst;
-		m_pFirst = pNext;
+void pf_Fragments::purgeFrags()
+{
+	if (m_pRoot != m_pLeaf) {
+		delete_and_purge_tree(m_pRoot);
 	}
-	
-	m_pLast = NULL;
+	m_pRoot = m_pLeaf;
 }
 
 void pf_Fragments::appendFrag(pf_Frag * pf)
@@ -198,7 +193,7 @@ void pf_Fragments::insertFragBefore(pf_Frag * pfPlace, pf_Frag * pfNew)
 void pf_Fragments::unlinkFrag(pf_Frag * pf)
 {
 	// NOTE:  it is the caller's responsibility to delete pf if appropriate.
-        UT_DEBUGMSG(("Unlinking frag %p \n",pf));
+        xxx_UT_DEBUGMSG(("Unlinking frag %p \n",pf));
 	UT_return_if_fail (pf->getType() != pf_Frag::PFT_EndOfDoc);
 	// verifyDoc();
 	Iterator it(this,pf->_getNode());
@@ -606,7 +601,6 @@ pf_Fragments::fixSize(Iterator it)
 {
 	UT_ASSERT(it.is_valid());
 	Node* pn = it.getNode();
-	pf_Frag* item = NULL;
 	int delta = 0;
    
 	if (pn == m_pRoot)
@@ -643,8 +637,6 @@ pf_Fragments::fixSize(Iterator it)
 	/* if the m_lengthLeft of that head changed, propagate the change to our parents */
 	while (pn != m_pRoot && delta != 0)
 	{
-		item = pn->item;
-	
 		if (pn->parent->left == pn)
 			pn->parent->item->accLeftTreeLength(delta);
 
@@ -1105,6 +1097,21 @@ pf_Fragments::_calculateSize(Node* x) const
 	return x->item->getLeftTreeLength() + x->item->getLength() + _calculateSize(x->right);
 }
 
+void
+pf_Fragments::delete_and_purge_tree(Node* node)
+{
+	if (node->left != m_pLeaf) {
+		delete_and_purge_tree(node->left);
+	}
+	if (node->right != m_pLeaf) {
+		delete_and_purge_tree(node->right);
+	}
+	if(node->item) {
+		delete node->item;
+	}
+	delete node;
+}
+
 void
 pf_Fragments::delete_tree(Node* node)
 {
@@ -1164,10 +1171,10 @@ pf_Fragments::checkInvariants() const
 	// These iterators should be ConstIterators
 	// ConstIterator end(end());
 	// ConstIterator it(begin());
-	Iterator end(const_cast<pf_Fragments* const> (this));
+	Iterator end_(const_cast<pf_Fragments* const> (this));
 	Iterator it(const_cast<pf_Fragments* const> (this), const_cast<Node*> (_first()));
 
-	if (it != end)
+	if (it != end_)
 		nb_blacks = _countBlackNodes(it++);
 
 	if (nb_blacks < 0)
@@ -1176,7 +1183,7 @@ pf_Fragments::checkInvariants() const
 	if (!checkSizeInvariant(m_pRoot, NULL))
 		return false;
 	
-	for (; it != end; ++it)
+	for (; it != end_; ++it)
 	{
 		Node *pn = it.getNode();
 		
