@@ -15,8 +15,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include "xap_App.h"
@@ -412,7 +412,8 @@ static const char * s_GetMenuItemComputedLabel_Fn (const EV_Menu_Label * pLabel,
 
     bool first = true;
 
-    for (NSString *key in [options copy])
+	NSEnumerator* keyEnumerator = [options keyEnumerator];
+    while(NSString *key = [keyEnumerator nextObject])
     {
         NSString *value = (NSString *) [options objectForKey:key];
         if (value)
