@@ -13,8 +13,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -179,9 +179,13 @@ GtkWidget * AP_UnixDialog_HdrFtr::_constructWindow (void)
 
     const char * uiFileName;
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-	uiFileName = "ap_UnixHildonDialog_HdrFtr.xml";
+	uiFileName = "ap_UnixHildonDialog_HdrFtr.ui";
 #else
-	uiFileName = "ap_UnixDialog_HdrFtr.xml";
+#if GTK_CHECK_VERSION(3,0,0)
+	uiFileName = "ap_UnixDialog_HdrFtr.ui";
+#else
+	uiFileName = "ap_UnixDialog_HdrFtr-2.ui";
+#endif
 #endif
 
     GtkBuilder * builder = newDialogBuilder(uiFileName);
@@ -201,9 +205,9 @@ GtkWidget * AP_UnixDialog_HdrFtr::_constructWindow (void)
 	m_spinAdj = gtk_spin_button_get_adjustment( GTK_SPIN_BUTTON(m_wSpin) );
 	
 	// set the dialog title
-	UT_UTF8String s;
+	std::string s;
 	pSS->getValueUTF8(AP_STRING_ID_DLG_HdrFtr_Title,s);
-	abiDialogSetTitle(window, s.utf8_str());
+	abiDialogSetTitle(window, "%s", s.c_str());
 
 	// localize the strings in our dialog
 	
