@@ -14,8 +14,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
+ * 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -68,7 +68,7 @@ void  AP_UnixDialog_WordCount::activate(void)
 	UT_ASSERT (m_windowMain);
 	
 	ConstructWindowName();
-	setWidgetLabel(DIALOG_WID, m_WindowName);
+	setWidgetLabel(DIALOG_WID, std::string(m_WindowName));
 	setCountFromActiveFrame ();
 	updateDialogData();
 	gdk_window_raise (gtk_widget_get_window(m_windowMain));
@@ -135,7 +135,7 @@ void AP_UnixDialog_WordCount::notifyActiveFrame(XAP_Frame * /*pFrame*/)
 	// FIXME put that in XP code
 	UT_ASSERT(m_windowMain);
 	ConstructWindowName();
-	setWidgetLabel(DIALOG_WID, m_WindowName);
+	setWidgetLabel(DIALOG_WID, std::string(m_WindowName));
 	setCountFromActiveFrame();
 	updateDialogData();
 }
@@ -219,7 +219,11 @@ XAP_Widget *AP_UnixDialog_WordCount::getWidget(xap_widget_id wid)
 
 void AP_UnixDialog_WordCount::constructDialog(void)
 {	
-    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_WordCount.xml");
+#if GTK_CHECK_VERSION(3,0,0)
+    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_WordCount.ui");
+#else
+    GtkBuilder * builder = newDialogBuilder("ap_UnixDialog_WordCount-2.ui");
+#endif
 
 	m_windowMain   = GTK_WIDGET(gtk_builder_get_object(builder, "ap_UnixDialog_WordCount"));
 	m_labelWCount  = GTK_WIDGET(gtk_builder_get_object(builder, "lbWordsVal"));
