@@ -500,18 +500,40 @@ void AP_UnixFrameImpl::_setScrollRange(apufi_ScrollType scrollType, int iValue,
 	}
 }
 
+#define COLOR_MIX 0.67   //COLOR_MIX should be between 0 and 1
+
 UT_RGBColor AP_UnixFrameImpl::getColorSelBackground () const
 {
     if( XAP_App::getApp()->getNoGUI() ) 
         return(UT_RGBColor(0,0,0));
 
     UT_return_val_if_fail(m_dArea, UT_RGBColor(0,0,0));
-    // owen says that any widget should be ok, not just text widgets
+
 #if GTK_CHECK_VERSION(3,0,0)
-    GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
-    GdkRGBA rgba;
-    gtk_style_context_get_background_color(pCtxt, GTK_STATE_FLAG_SELECTED, &rgba);
-    return UT_RGBColor (rgba.red * 255, rgba.green * 255, rgba.blue * 255);
+    // Bug 13762 guess colours for the selection.
+    // Code copied from gr_UnixCairoGraphics.
+
+    // guess colours
+    // WHITE
+    GdkRGBA rgba2;
+    rgba2.red = 1.;
+    rgba2.green = 1.;
+    rgba2.blue = 1.;
+    rgba2.alpha = 1;
+    // guess colours.
+    // BLACK
+    GdkRGBA rgba1;
+    rgba1.red = 0.;
+    rgba1.green = 0.;
+    rgba1.blue = 0.;
+    rgba1.alpha = 1;
+
+    GdkRGBA rgba_;
+    rgba_.red = rgba1.red*(1.-COLOR_MIX) + rgba2.red*COLOR_MIX;
+    rgba_.green = rgba1.green*(1.-COLOR_MIX) + rgba2.green*COLOR_MIX;
+    rgba_.blue = rgba1.blue*(1.-COLOR_MIX) + rgba2.blue*COLOR_MIX;
+
+    return UT_RGBColor(rgba_.red * 255, rgba_.green * 255, rgba_.blue * 255);
 #else
     GdkColor clr = m_dArea->style->base[GTK_STATE_SELECTED];
     return UT_RGBColor (clr.red >> 8, clr.green >> 8, clr.blue >> 8);
@@ -520,22 +542,8 @@ UT_RGBColor AP_UnixFrameImpl::getColorSelBackground () const
 
 UT_RGBColor AP_UnixFrameImpl::getColorSelForeground () const
 {
-  UT_return_val_if_fail(m_dArea, UT_RGBColor(0,0,0));
-  
-  // owen says that any widget should be ok, not just text widgets
 #if GTK_CHECK_VERSION(3,0,0)
-  GtkStateFlags state;
-  
-  // our text widget has focus
-  if (gtk_widget_has_focus(m_dArea))
-    state = GTK_STATE_FLAG_SELECTED;
-  else
-    state = GTK_STATE_FLAG_ACTIVE;
-  
-  GtkStyleContext *pCtxt = gtk_widget_get_style_context(m_dArea);
-  GdkRGBA rgba;
-  gtk_style_context_get_color(pCtxt, state, &rgba);
-  return UT_RGBColor (rgba.red * 255, rgba.green * 255, rgba.blue * 255);
+  return UT_RGBColor(0,0,0);
 #else  
   gint state;
   
