@@ -6,16 +6,16 @@
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
  */
 
 #ifndef AP_UNIXFRAMEIMPL_H
@@ -36,7 +36,7 @@ enum apufi_ScrollType { apufi_scrollX, apufi_scrollY }; // can we use namespaces
 class AP_UnixFrameImpl : public XAP_UnixFrameImpl
 {
  public:
-	AP_UnixFrameImpl(AP_UnixFrame *pUnixFrame); 
+	AP_UnixFrameImpl(AP_UnixFrame *pUnixFrame);
 	virtual XAP_FrameImpl * createInstance(XAP_Frame *pFrame);
 
 	virtual UT_RGBColor getColorSelBackground () const;
@@ -48,6 +48,8 @@ class AP_UnixFrameImpl : public XAP_UnixFrameImpl
 	GtkWidget * getDrawingArea() const {return m_dArea;}
 	static gboolean ap_focus_in_event (GtkWidget * drawing_area, GdkEventCrossing *event, AP_UnixFrameImpl * me);
 	static gboolean ap_focus_out_event (GtkWidget * drawing_area, GdkEventCrossing *event, AP_UnixFrameImpl * me);
+	virtual GtkWidget * getViewWidget(void) const
+	{ return m_dArea; }
 
  protected:
 	friend class AP_UnixFrame;
